@@ -356,6 +356,27 @@ $DIRECTIVES->{matches} = {
     }
 };
 
+
+$DIRECTIVES->{options} = {
+    mixin     => 1,
+    field     => 1,
+    multi     => 0,
+    validator => sub {
+        my ( $directive, $value, $field, $class ) = @_;
+        if ($value) {
+            # build the regex
+            my (@options) = split /\,\s?/, $directive;
+            unless ( grep { $value =~ /^$_$/ } @options ) {
+                my $handle  = $field->{label} || $field->{name};
+                my $error = "$handle must be " . join " or ", @options;
+                $class->error( $field, $error );
+                return 0;
+            }
+        }
+        return 1;
+    }
+};
+
 # mixin/field types store
 has 'directives' => (
     is      => 'rw',
@@ -1044,7 +1065,7 @@ Validation::Class - Centralized Input Validation For Any Application
 
 =head1 VERSION
 
-version 0.111903
+version 0.111904
 
 =head1 SYNOPSIS
 
@@ -1473,6 +1494,14 @@ declarations:
         ...
     };
 
+=head2 options
+
+    # the options directive
+    field 'status'  => {
+        options => 'Active, Inactive',
+        ...
+    };
+
 =head1 EXECUTING A VALIDATION CLASS
 
 The following is an example of how to use you constructed validation class in
